@@ -9,7 +9,6 @@ from sklearn.feature_extraction.text import CountVectorizer
 
 from phrase_counter.cleaner import cleaner, fetch_page_text
 
-# ---------------------- Getting stop words list ----------------------
 STOP_PATH = f"{Path(__file__).parent}/static/stop-words.txt"
 with open(STOP_PATH, "r", encoding="utf-8") as stop_file:
     STOP_LIST = stop_file.readlines()
@@ -18,12 +17,16 @@ with open(STOP_PATH, "r", encoding="utf-8") as stop_file:
 STOP_LIST = list(map(str.strip, STOP_LIST))
 
 
-def ingest_doc(doc: str, doc_type: str = "text") -> Any:
+def ingest_doc(
+    doc: str, doc_type: str = "TEXT", replace_stop: bool = False, tag_stop: bool = False
+) -> Any:
     """Counting phrases in the document.
 
     Args:
         doc: Document to be processed.
         doc_type: URL, TEXT, or HTML.
+        replace_stop: Whether to replace stop words or not
+        tag_stop: Whether to change status of stop words or not
 
     Returns:
         Dataframe with counts for each word.
@@ -47,7 +50,7 @@ def ingest_doc(doc: str, doc_type: str = "text") -> Any:
     else:
         raise Exception("Unknown value for doc_type argument.")
 
-    cleaned_text = cleaner(dirty_text)
+    cleaned_text = cleaner(dirty_text, replace_stop=replace_stop, stop_list=STOP_LIST)
 
     # ----------------- Initialization -----------------
     phrase_df = pd.DataFrame(columns=["bag", "count"])
@@ -81,9 +84,11 @@ def ingest_doc(doc: str, doc_type: str = "text") -> Any:
     phrase_df = phrase_df.groupby(["bag", "_key"]).agg({"count": "sum"}).reset_index()
 
     # Changing status to suggested stop for phrases that conatin stop words
-    phrase_df["status"] = phrase_df.apply(
-        lambda row: stop_word_detector(row["bag"]), axis=1
-    )
+    phrase_df["status"] = None
+    if tag_stop:
+        phrase_df["status"] = phrase_df.apply(
+            lambda row: stop_word_detector(row["bag"]), axis=1
+        )
     # Counting number of words in each bag
     phrase_df["length"] = phrase_df.apply(
         lambda row: len(str(row["bag"]).split()), axis=1
